@@ -40,6 +40,24 @@ void bd_plugin_spec_free (BDPluginSpec *spec) {
     g_free (spec);
 }
 
+/**
+ * bd_plugin_spec_new: (constructor)
+ * @name: %BDPlugin name, e.g. %BD_PLUGIN_LVM
+ * @so_name: (nullable): SO name of the plugin to load or %NULL for default
+ *
+ * Returns: (transfer full): a new plugin spec
+ */
+BDPluginSpec* bd_plugin_spec_new (BDPlugin name, const gchar *so_name) {
+    BDPluginSpec* ret = g_new0 (BDPluginSpec, 1);
+    ret->name = name;
+    /* FIXME: this should be const, but we are already allocating a new string in _copy
+    *         and freeing it in _free
+    */
+    ret->so_name = so_name ? g_strdup (so_name) : NULL;
+
+    return ret;
+}
+
 GType bd_plugin_spec_get_type (void) {
     static GType type = 0;
 
