@@ -35,7 +35,6 @@
 #define ZERO_INIT {0}
 #endif
 
-#define UNUSED __attribute__((unused))
 
 extern char **environ;
 
@@ -136,6 +135,37 @@ static void log_done (guint64 task_id, gint exit_code) {
     return;
 }
 
+static const gchar ** _append_extra_args (const gchar **argv, const BDExtraArg **extra) {
+    const gchar **args = NULL;
+    guint args_len = 0;
+    const BDExtraArg **extra_p = NULL;
+    const gchar **arg_p = NULL;
+    guint i = 0;
+
+    if (!extra)
+        return NULL;
+
+    args_len = g_strv_length ((gchar **) argv);
+    for (extra_p = extra; *extra_p; extra_p++) {
+        if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0))
+            args_len++;
+        if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0))
+            args_len++;
+    }
+
+    args = g_new0 (const gchar *, args_len + 1);
+    for (arg_p = argv; *arg_p; arg_p++)
+        args[i++] = *arg_p;
+    for (extra_p = extra; *extra_p; extra_p++) {
+        if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0))
+            args[i++] = (*extra_p)->opt;
+        if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0))
+            args[i++] = (*extra_p)->val;
+    }
+
+    return args;
+}
+
 /**
  * bd_utils_exec_and_report_error:
  * @argv: (array zero-terminated=1): the argv array for the call
@@ -166,52 +196,28 @@ gboolean bd_utils_exec_and_report_error_no_progress (const gchar **argv, const B
 }
 
 /**
- * bd_utils_exec_and_report_status_error:
+ * bd_utils_exec_and_capture_output_no_progress:
  * @argv: (array zero-terminated=1): the argv array for the call
  * @extra: (nullable) (array zero-terminated=1): extra arguments
- * @status: (out): place to store the status
+ * @output: (out) (optional): place to store stdout to
+ * @stderr: (out) (optional): place to store stderr to
+ * @status: (out): place to store the process return code
  * @error: (out) (optional): place to store error (if any)
  *
- * Returns: whether the @argv was successfully executed (no error and exit code 0) or not
+ * Returns: whether the @argv was successfully executed capturing the output or not
  */
-gboolean bd_utils_exec_and_report_status_error (const gchar **argv, const BDExtraArg **extra, gint *status, GError **error) {
+gboolean bd_utils_exec_and_capture_output_no_progress (const gchar **argv, const BDExtraArg **extra, gchar **output, gchar **stderr, gint *status, GError **error) {
     gboolean success = FALSE;
     gchar *stdout_data = NULL;
     gchar *stderr_data = NULL;
     guint64 task_id = 0;
     const gchar **args = NULL;
-    guint args_len = 0;
-    const gchar **arg_p = NULL;
-    const BDExtraArg **extra_p = NULL;
     gint exit_status = 0;
-    guint i = 0;
     gchar **old_env = NULL;
     gchar **new_env = NULL;
     GError *l_error = NULL;
 
-    if (extra) {
-        args_len = g_strv_length ((gchar **) argv);
-        for (extra_p=extra; *extra_p; extra_p++) {
-            if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0))
-                args_len++;
-            if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0))
-                args_len++;
-        }
-        args = g_new0 (const gchar*, args_len + 1);
-        for (arg_p=argv; *arg_p; arg_p++, i++)
-            args[i] = *arg_p;
-        for (extra_p=extra; *extra_p; extra_p++) {
-            if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0)) {
-                args[i] = (*extra_p)->opt;
-                i++;
-            }
-            if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0)) {
-                args[i] = (*extra_p)->val;
-                i++;
-            }
-        }
-        args[i] = NULL;
-    }
+    args = _append_extra_args (argv, extra);
 
     old_env = g_get_environ ();
     new_env = g_environ_setenv (old_env, "LC_ALL", "C.UTF-8", TRUE);
@@ -220,14 +226,13 @@ gboolean bd_utils_exec_and_report_status_error (const gchar **argv, const BDExtr
     task_id = log_running (args ? args : argv);
     success = g_spawn_sync (NULL, args ? (gchar **) args : (gchar **) argv, new_env, G_SPAWN_SEARCH_PATH,
                             NULL, NULL, &stdout_data, &stderr_data, &exit_status, error);
+    g_strfreev (new_env);
     if (!success) {
         /* error is already populated from the call */
-        g_strfreev (new_env);
         g_free (stdout_data);
         g_free (stderr_data);
         return FALSE;
     }
-    g_strfreev (new_env);
 
     /* g_spawn_sync set the status in the same way waitpid() does, we need
        to get the process exit code manually (this is similar to calling
@@ -255,26 +260,47 @@ gboolean bd_utils_exec_and_report_status_error (const gchar **argv, const BDExtr
     log_done (task_id, *status);
 
     g_free (args);
+    if (output)
+        *output = stdout_data;
+    else
+        g_free (stdout_data);
+    if (stderr)
+        *stderr = stderr_data;
+    else
+        g_free (stderr_data);
 
-    if (*status != 0) {
-        if (stderr_data && (g_strcmp0 ("", stderr_data) != 0)) {
-            g_set_error (error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED,
-                         "Process reported exit code %d: %s", *status, stderr_data);
-            g_free (stdout_data);
-        } else {
-            g_set_error (error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED,
-                         "Process reported exit code %d: %s", *status, stdout_data);
-            g_free (stderr_data);
-        }
-
-        return FALSE;
-    }
-
-    g_free (stdout_data);
-    g_free (stderr_data);
     return TRUE;
 }
 
+/**
+ * bd_utils_exec_and_report_status_error:
+ * @argv: (array zero-terminated=1): the argv array for the call
+ * @extra: (nullable) (array zero-terminated=1): extra arguments
+ * @status: (out): place to store the status
+ * @error: (out) (optional): place to store error (if any)
+ *
+ * Returns: whether the @argv was successfully executed (no error and exit code 0) or not
+ */
+gboolean bd_utils_exec_and_report_status_error (const gchar **argv, const BDExtraArg **extra, gint *status, GError **error) {
+    gboolean ret;
+    gchar *stdout_data = NULL;
+    gchar *stderr_data = NULL;
+
+    ret = bd_utils_exec_and_capture_output_no_progress (argv, extra, &stdout_data, &stderr_data, status, error);
+
+    if (ret && *status != 0) {
+        if (stderr_data && (g_strcmp0 ("", stderr_data) != 0))
+            g_set_error (error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED,
+                         "Process reported exit code %d: %s", *status, stderr_data);
+        else
+            g_set_error (error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED,
+                         "Process reported exit code %d: %s", *status, stdout_data);
+        ret = FALSE;
+    }
+    g_free (stdout_data);
+    g_free (stderr_data);
+    return ret;
+}
 
 /* buffer size in bytes used to read from stdout and stderr */
 #define _EXEC_BUF_SIZE 64*1024
@@ -359,10 +385,7 @@ _process_fd_event (gint fd, struct pollfd *poll_fd, GString *read_buffer, GStrin
 
 static gboolean _utils_exec_and_report_progress (const gchar **argv, const BDExtraArg **extra, BDUtilsProgExtract prog_extract, const gchar *input, gint *proc_status, gchar **stdout, gchar **stderr, GError **error) {
     const gchar **args = NULL;
-    guint args_len = 0;
-    const gchar **arg_p = NULL;
     gchar *args_str = NULL;
-    const BDExtraArg **extra_p = NULL;
     guint64 task_id = 0;
     guint64 progress_id = 0;
     gchar *msg = NULL;
@@ -374,7 +397,6 @@ static gboolean _utils_exec_and_report_progress (const gchar **argv, const BDExt
     gint status = 0;
     gboolean ret = FALSE;
     gint poll_status = 0;
-    guint i = 0;
     guint8 completion = 0;
     struct pollfd fds[2] = { ZERO_INIT, ZERO_INIT };
     int flags;
@@ -391,30 +413,7 @@ static gboolean _utils_exec_and_report_progress (const gchar **argv, const BDExt
     gboolean success = TRUE;
     GError *l_error = NULL;
 
-    /* TODO: share this code between functions */
-    if (extra) {
-        args_len = g_strv_length ((gchar **) argv);
-        for (extra_p=extra; *extra_p; extra_p++) {
-            if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0))
-                args_len++;
-            if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0))
-                args_len++;
-        }
-        args = g_new0 (const gchar*, args_len + 1);
-        for (arg_p=argv; *arg_p; arg_p++, i++)
-            args[i] = *arg_p;
-        for (extra_p=extra; *extra_p; extra_p++) {
-            if ((*extra_p)->opt && (g_strcmp0 ((*extra_p)->opt, "") != 0)) {
-                args[i] = (*extra_p)->opt;
-                i++;
-            }
-            if ((*extra_p)->val && (g_strcmp0 ((*extra_p)->val, "") != 0)) {
-                args[i] = (*extra_p)->val;
-                i++;
-            }
-        }
-        args[i] = NULL;
-    }
+    args = _append_extra_args (argv, extra);
 
     task_id = log_running (args ? args : argv);
 
@@ -728,6 +727,10 @@ gint bd_utils_version_cmp (const gchar *ver_string1, const gchar *ver_string2, G
  *                  info or %NULL if only version is printed by "$ @util @version_arg"
  * @error: (out) (optional): place to store error (if any)
  *
+ * Note: Both supplied @version and parsed result using @version_regexp must be in format
+ *       `X[.Y[.Z[.Z2[.Z3...[-R]]]]]` where all components are natural numbers, see
+ *       %bd_utils_version_cmp for details.
+ *
  * Returns: whether the @util is available in a version >= @version or not
  *          (@error is set in such case).
  */
@@ -825,7 +828,7 @@ gboolean bd_utils_check_util_version (const gchar *util, const gchar *version, c
  *
  * Returns: whether progress reporting was successfully initialized or not
  */
-gboolean bd_utils_init_prog_reporting (BDUtilsProgFunc new_prog_func, GError **error UNUSED) {
+gboolean bd_utils_init_prog_reporting (BDUtilsProgFunc new_prog_func, GError **error G_GNUC_UNUSED) {
     /* XXX: the error attribute will likely be used in the future when this
        function gets more complicated */
 
@@ -843,7 +846,7 @@ gboolean bd_utils_init_prog_reporting (BDUtilsProgFunc new_prog_func, GError **e
  *
  * Returns: whether progress reporting was successfully initialized or not
  */
-gboolean bd_utils_init_prog_reporting_thread (BDUtilsProgFunc new_prog_func, GError **error UNUSED) {
+gboolean bd_utils_init_prog_reporting_thread (BDUtilsProgFunc new_prog_func, GError **error G_GNUC_UNUSED) {
     /* XXX: the error attribute will likely be used in the future when this
        function gets more complicated */
 
@@ -852,7 +855,8 @@ gboolean bd_utils_init_prog_reporting_thread (BDUtilsProgFunc new_prog_func, GEr
     return TRUE;
 }
 
-static void thread_progress_muted (guint64 task_id UNUSED, BDUtilsProgStatus status UNUSED, guint8 completion UNUSED, gchar *msg UNUSED) {
+static void thread_progress_muted (guint64 task_id G_GNUC_UNUSED, BDUtilsProgStatus status G_GNUC_UNUSED,
+                                   guint8 completion G_GNUC_UNUSED, gchar *msg G_GNUC_UNUSED) {
     /* This function serves as a special value for the progress reporting
      * function to detect that nothing is done here. If clients use their own
      * empty function then bd_utils_prog_reporting_initialized will return TRUE
@@ -867,7 +871,7 @@ static void thread_progress_muted (guint64 task_id UNUSED, BDUtilsProgStatus sta
  * Returns: whether progress reporting for the current thread was successfully
  * muted (deinitialized even in presence of a global reporting function) or not
  */
-gboolean bd_utils_mute_prog_reporting_thread (GError **error UNUSED) {
+gboolean bd_utils_mute_prog_reporting_thread (GError **error G_GNUC_UNUSED) {
     /* XXX: the error attribute will likely be used in the future when this
        function gets more complicated */
 
