@@ -17,12 +17,18 @@
 #define PiB PEBIBYTE
 #define EiB EXBIBYTE
 
-#define BD_UTILS_SIZE_ERROR bd_utils_size_error_quark ()
-typedef enum {
-    BD_UTILS_SIZE_ERROR_INVALID_SPEC,
-} BDUtilsSizeError;
+#define KILOBYTE *1000ULL
+#define MEGABYTE *1000ULL KILOBYTE
+#define GIGABYTE *1000ULL MEGABYTE
+#define TERABYTE *1000ULL GIGABYTE
+#define PETABYTE *1000ULL TERABYTE
+#define EXABYTE *1000ULL PETABYTE
 
-gchar* bd_utils_size_human_readable (guint64 size);
-guint64 bd_utils_size_from_spec (gchar *spec, GError **error);
+#define KB KILOBYTE
+#define MB MEGABYTE
+#define GB GIGABYTE
+#define TB TERABYTE
+#define PB PETABYTE
+#define EB EXABYTE
 
 #endif /* BD_UTILS_SIZES */
