@@ -25,7 +25,7 @@ class NVMeTest(unittest.TestCase):
             raise unittest.SkipTest("nvme executable (nvme-cli package) not found in $PATH, skipping.")
         if not shutil.which("nvmetcli"):
             raise unittest.SkipTest("nvmetcli executable not found in $PATH, skipping.")
-        ret, out, err = run_command("modprobe nvme-fabrics")
+        ret, _out, _err = run_command("modprobe nvme-fabrics")
         if ret != 0:
             raise unittest.SkipTest("nvme-fabrics kernel module unavailable, skipping.")
 
@@ -44,7 +44,7 @@ class NVMeTest(unittest.TestCase):
 class NVMePluginVersionTestCase(NVMeTest):
     @tag_test(TestTags.NOSTORAGE)
     def test_plugin_version(self):
-       self.assertEqual(BlockDev.get_plugin_soname(BlockDev.Plugin.NVME), "libbd_nvme.so.3")
+        self.assertEqual(BlockDev.get_plugin_soname(BlockDev.Plugin.NVME), "libbd_nvme.so.3")
 
     @tag_test(TestTags.NOSTORAGE)
     def test_availability(self):
@@ -283,7 +283,7 @@ class NVMeTestCase(NVMeTest):
         with self.assertRaisesRegex(GLib.GError, r".*Failed to open device .*': No such file or directory"):
             BlockDev.nvme_get_sanitize_log("/dev/nonexistent")
 
-        message = r"NVMe Get Log Page - Sanitize Status Log command error: Invalid Field in Command: A reserved coded value or an unsupported value in a defined field|NVMe Get Log Page - Sanitize Status Log command error: unrecognized"
+        message = r"NVMe Get Log Page - Sanitize Status Log command error: (Invalid Field in Command: A reserved coded value or an unsupported value in a defined field|unrecognized|No such file or directory)"
         with self.assertRaisesRegex(GLib.GError, message):
             # Cannot retrieve sanitize log on a nvme target loop devices
             BlockDev.nvme_get_sanitize_log(self.nvme_dev)
@@ -416,7 +416,7 @@ class NVMeFabricsTestCase(NVMeTest):
         NUM_NS = 3
 
         # test that no device node exists for given subsystem nqn
-        ctrls = find_nvme_ctrl_devs_for_subnqn(self.SUBNQN)
+        ctrls = find_nvme_ctrl_devs_for_subnqn(self.SUBNQN, wait_for_ready=False)
         self.assertEqual(len(ctrls), 0)
 
         self._setup_target(NUM_NS)
@@ -514,13 +514,11 @@ class NVMeFabricsTestCase(NVMeTest):
             self.addCleanup(write_file, HOSTNQN_PATH, saved_hostnqn)
         except:
             self.addCleanup(self._safe_unlink, HOSTNQN_PATH)
-            pass
         try:
             saved_hostid = read_file(HOSTID_PATH)
             self.addCleanup(write_file, HOSTID_PATH, saved_hostid)
         except:
             self.addCleanup(self._safe_unlink, HOSTID_PATH)
-            pass
 
         self._safe_unlink(HOSTNQN_PATH)
         self._safe_unlink(HOSTID_PATH)
