@@ -1,12 +1,9 @@
 import unittest
 import os
-import re
-import glob
-import time
 import shutil
 import overrides_hack
 
-from utils import run, create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, TestTags, tag_test, write_file, run_command, required_plugins
+from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, TestTags, tag_test, required_plugins, setup_scsi_debug, clean_scsi_debug
 
 import gi
 gi.require_version('GLib', '2.0')
@@ -60,32 +57,9 @@ class SmartmontoolsTest(unittest.TestCase):
             pass
         os.unlink(self.loop_dev_file)
 
-    def _setup_scsi_debug(self):
-        res, _out, _err = run_command('modprobe scsi_debug')
-        self.assertEqual(res, 0)
-        dirs = []
-        while len(dirs) < 1:
-            dirs = glob.glob('/sys/bus/pseudo/drivers/scsi_debug/adapter*/host*/target*/*:*/block')
-            time.sleep(0.1)
-        self.scsi_debug_dev = os.listdir(dirs[0])
-        self.assertEqual(len(self.scsi_debug_dev), 1)
-        self.scsi_debug_dev = '/dev/' + self.scsi_debug_dev[0]
-        self.assertTrue(os.path.exists(self.scsi_debug_dev))
-
-    def _clean_scsi_debug(self):
-        try:
-            device = self.scsi_debug_dev.split('/')[-1]
-            if os.path.exists('/sys/block/' + device):
-                self.write_file('/sys/block/%s/device/delete' % device, '1')
-            while os.path.exists(device):
-                time.sleep(0.1)
-            self.run_command('modprobe -r scsi_debug')
-        except:
-            pass
-
     @tag_test(TestTags.NOSTORAGE)
     def test_plugin_version(self):
-       self.assertEqual(BlockDev.get_plugin_soname(BlockDev.Plugin.SMART), "libbd_smartmontools.so.3")
+        self.assertEqual(BlockDev.get_plugin_soname(BlockDev.Plugin.SMART), "libbd_smartmontools.so.3")
 
     @tag_test(TestTags.CORE)
     def test_ata_info(self):
@@ -133,8 +107,8 @@ class SmartmontoolsTest(unittest.TestCase):
             BlockDev.smart_ata_get_info(self.loop_dev, [BlockDev.ExtraArg.new("--device=ata", "")])
 
         # scsi_debug
-        self._setup_scsi_debug()
-        self.addCleanup(self._clean_scsi_debug)
+        self.scsi_debug_dev = setup_scsi_debug()
+        self.addCleanup(clean_scsi_debug, self.scsi_debug_dev)
         msg = r"Error parsing smartctl JSON data: The member .ata_smart_data. is not defined in the object at the current position."
         with self.assertRaisesRegex(GLib.GError, msg):
             BlockDev.smart_ata_get_info(self.scsi_debug_dev, None)
@@ -281,8 +255,8 @@ class SmartmontoolsTest(unittest.TestCase):
             BlockDev.smart_set_enabled(self.loop_dev, True, [BlockDev.ExtraArg.new("--device=ata", "")])
 
         # scsi_debug
-        self._setup_scsi_debug()
-        self.addCleanup(self._clean_scsi_debug)
+        self.scsi_debug_dev = setup_scsi_debug()
+        self.addCleanup(clean_scsi_debug, self.scsi_debug_dev)
         BlockDev.smart_set_enabled(self.scsi_debug_dev, False)
         BlockDev.smart_set_enabled(self.scsi_debug_dev, True)
         BlockDev.smart_set_enabled(self.scsi_debug_dev, False, [BlockDev.ExtraArg.new("--device=scsi", "")])
@@ -345,8 +319,8 @@ class SmartmontoolsTest(unittest.TestCase):
                 BlockDev.smart_device_self_test(self.loop_dev, t, [BlockDev.ExtraArg.new("--device=scsi", "")])
 
         # scsi_debug
-        self._setup_scsi_debug()
-        self.addCleanup(self._clean_scsi_debug)
+        self.scsi_debug_dev = setup_scsi_debug()
+        self.addCleanup(clean_scsi_debug, self.scsi_debug_dev)
         for t in [BlockDev.SmartSelfTestOp.OFFLINE, BlockDev.SmartSelfTestOp.SHORT,
                   BlockDev.SmartSelfTestOp.LONG, BlockDev.SmartSelfTestOp.CONVEYANCE,
                   BlockDev.SmartSelfTestOp.ABORT]:
@@ -375,6 +349,7 @@ class SmartmontoolsTest(unittest.TestCase):
 
         # LIO device (SCSI)
         self._setup_lio()
+        self.addCleanup(self._clean_lio)
         msg = r"Error getting SCSI SMART info: Some SMART or other ATA command to the disk failed, or there was a checksum error in a SMART data structure."
         with self.assertRaisesRegex(GLib.GError, msg):
             BlockDev.smart_scsi_get_info(self.lio_dev, None)
@@ -397,8 +372,8 @@ class SmartmontoolsTest(unittest.TestCase):
             BlockDev.smart_scsi_get_info(self.loop_dev, [BlockDev.ExtraArg.new("--device=ata", "")])
 
         # scsi_debug
-        self._setup_scsi_debug()
-        self.addCleanup(self._clean_scsi_debug)
+        self.scsi_debug_dev = setup_scsi_debug()
+        self.addCleanup(clean_scsi_debug, self.scsi_debug_dev)
         msg = r"Error getting SCSI SMART info: Some SMART or other ATA command to the disk failed, or there was a checksum error in a SMART data structure."
         with self.assertRaisesRegex(GLib.GError, msg):
             BlockDev.smart_scsi_get_info(self.scsi_debug_dev, None)
