@@ -81,7 +81,7 @@ def fake_utils(path="."):
 ALL_UTILS = {"lvm", "btrfs", "mkswap", "swaplabel", "multipath", "mpathconf", "dmsetup", "mdadm",
              "mkfs.exfat", "fsck.exfat", "tune.exfat",
              "mke2fs", "e2fsck", "tune2fs", "dumpe2fs", "resize2fs",
-             "mkfs.f2fs", "fsck.f2fs", "fsck.f2fs", "dump.f2fs", "resize.f2fs",
+             "mkfs.f2fs", "fsck.f2fs", "dump.f2fs", "resize.f2fs",
              "mkfs.nilfs2", "nilfs-tune", "nilfs-resize",
              "mkntfs", "ntfsfix", "ntfsresize", "ntfslabel", "ntfsinfo",
              "mkfs.vfat", "fatlabel", "fsck.vfat", "vfat-resize",
@@ -231,11 +231,86 @@ def delete_lio_device(dev_path):
     else:
         raise RuntimeError("Unknown device '%s'" % dev_path)
 
-def find_nvme_ctrl_devs_for_subnqn(subnqn):
+
+def setup_scsi_debug():
+    res, out, err = run_command('modprobe scsi_debug')
+    if res != 0:
+        raise RuntimeError("Failed to load scsi_debug module: %s %s" % (out, err))
+    dirs = []
+    n_tries = 0
+    while len(dirs) < 1 and n_tries < 5:
+        dirs = glob.glob('/sys/bus/pseudo/drivers/scsi_debug/adapter*/host*/target*/*:*/block')
+        time.sleep(0.5)
+        n_tries += 1
+    if len(dirs) < 1:
+        raise RuntimeError("Failed to setup SCSI debug device for testing")
+    scsi_debug_dev = os.listdir(dirs[0])
+    if len(scsi_debug_dev) != 1:
+        raise RuntimeError("Failed to setup SCSI debug device for testing")
+
+    scsi_debug_dev = '/dev/' + scsi_debug_dev[0]
+    if not os.path.exists(scsi_debug_dev):
+        raise RuntimeError("Failed to setup SCSI debug device for testing")
+
+    return scsi_debug_dev
+
+
+def clean_scsi_debug(scsi_debug_dev):
+    try:
+        device = scsi_debug_dev.split('/')[-1]
+        if os.path.exists('/sys/block/' + device):
+            write_file('/sys/block/%s/device/delete' % device, '1')
+        n_tries = 0
+        while os.path.exists(device) and n_tries < 5:
+            time.sleep(0.5)
+            n_tries += 1
+        n_tries = 0
+        while n_tries < 5:
+            res, _out, _err = run_command('modprobe -r scsi_debug')
+            if res == 0:
+                break
+            time.sleep(0.5)
+            n_tries += 1
+    except:
+        pass
+
+def _wait_for_nvme_controllers_ready(subnqn, timeout=3):
+    """
+    Wait for NVMe controllers with matching subsystem NQN to be in live state
+    
+    :param str subnqn: subsystem nqn to match controllers against
+    :param int timeout: timeout in seconds (default: 3)
+    """
+    start_time = time.time()
+    
+    while time.time() - start_time < timeout:
+        try:
+            for ctrl_path in glob.glob("/sys/class/nvme/nvme*/"):
+                state_file = os.path.join(ctrl_path, "state")
+                subsysnqn_file = os.path.join(ctrl_path, "subsysnqn")
+                try:
+                    state = read_file(state_file).strip()
+                    controller_subnqn = read_file(subsysnqn_file).strip()
+                    if state == "live" and controller_subnqn == subnqn:
+                        # Found a matching live controller
+                        os.system("udevadm settle")
+                        return
+                except:
+                    continue
+                
+        except:
+            pass
+        
+        time.sleep(1)
+    
+    os.system("udevadm settle")
+
+def find_nvme_ctrl_devs_for_subnqn(subnqn, wait_for_ready=True):
     """
     Find NVMe controller devices for the specified subsystem nqn
 
     :param str subnqn: subsystem nqn
+    :param bool wait_for_ready: whether to wait for controllers to be ready (default: True)
     """
 
     def _check_subsys(subsys, dev_paths):
@@ -252,6 +327,9 @@ def find_nvme_ctrl_devs_for_subnqn(subnqn):
                 except:
                     pass
 
+    # Wait for controllers to be ready if requested
+    if wait_for_ready:
+        _wait_for_nvme_controllers_ready(subnqn)
     ret, out, err = run_command("nvme list --output-format=json --verbose")
     if ret != 0:
         raise RuntimeError("Error getting NVMe list: '%s %s'" % (out, err))
@@ -274,11 +352,12 @@ def find_nvme_ctrl_devs_for_subnqn(subnqn):
     return dev_paths
 
 
-def find_nvme_ns_devs_for_subnqn(subnqn):
+def find_nvme_ns_devs_for_subnqn(subnqn, wait_for_ready=True):
     """
     Find NVMe namespace block devices for the specified subsystem nqn
 
     :param str subnqn: subsystem nqn
+    :param bool wait_for_ready: whether to wait for controllers to be ready (default: True)
     """
 
     def _check_namespaces(node, ns_dev_paths):
@@ -301,6 +380,8 @@ def find_nvme_ns_devs_for_subnqn(subnqn):
                     if 'Namespaces' in ctrl:
                         _check_namespaces(ctrl, ns_dev_paths)
 
+    if wait_for_ready:
+        _wait_for_nvme_controllers_ready(subnqn)
     ret, out, err = run_command("nvme list --output-format=json --verbose")
     if ret != 0:
         raise RuntimeError("Error getting NVMe list: '%s %s'" % (out, err))
