@@ -78,9 +78,16 @@ class UtilsExecLoggingTest(UtilsTestCase):
         succ = BlockDev.utils_exec_and_report_error(["true"])
         self.assertTrue(succ)
 
+        succ = BlockDev.utils_exec_and_capture_output_no_progress(["true"])
+        self.assertTrue(succ)
+
         with self.assertRaisesRegex(GLib.GError, r"Process reported exit code 1"):
             succ = BlockDev.utils_exec_and_report_error(["/bin/false"])
 
+        succ, out, stderr, status = BlockDev.utils_exec_and_capture_output_no_progress(["/bin/false"])
+        self.assertTrue(succ)
+        self.assertEqual(status, 1)
+
         succ, out = BlockDev.utils_exec_and_capture_output(["echo", "hi"])
         self.assertTrue(succ)
         self.assertEqual(out, "hi\n")
@@ -247,6 +254,15 @@ class UtilsExecLoggingTest(UtilsTestCase):
         self.assertTrue(succ)
         self.assertGreater(len(out), cnt)
 
+        (succ, out, stderr, status)  = BlockDev.utils_exec_and_capture_output_no_progress(["bash", "-c", r"for i in {1..%d}; do echo -n .; echo -n \# >&2; if [ $(($i%%500)) -eq 0 ]; then echo ''; echo '' >&2; fi; done" % cnt])
+        self.assertTrue(succ)
+        self.assertGreater(len(out), cnt)
+
+        (succ, out, stderr, status) = BlockDev.utils_exec_and_capture_output_no_progress(["bash", "-c", r"for i in {1..%d}; do echo -n . >&2; echo -n \# >&2; if [ $(($i%%500)) -eq 0 ]; then echo '' >&2; fi; done; exit 123" % cnt])
+        self.assertTrue(succ)
+        self.assertEqual(status, 123)
+        self.assertEqual(len(out), 0)
+        self.assertGreater(len(stderr), cnt)
 
     EXEC_PROGRESS_MSG = "Aloha, I'm the progress line you should match."
 
@@ -446,17 +462,17 @@ class UtilsDevUtilsSymlinksTestCase(UtilsTestCase):
         self.assertGreaterEqual(len(symlinks), 2)
 
         # create an LV to get a device with more symlinks
-        ret, _out, _err = run_command ("pvcreate %s" % self.loop_dev)
+        ret, _out, _err = run_command ("pvcreate %s --config \"devices {use_devicesfile = 0}\"" % self.loop_dev)
         self.assertEqual(ret, 0)
-        self.addCleanup(run_command, "pvremove %s" % self.loop_dev)
+        self.addCleanup(run_command, "pvremove %s --config \"devices {use_devicesfile = 0}\"" % self.loop_dev)
 
-        ret, _out, _err = run_command ("vgcreate utilsTestVG %s" % self.loop_dev)
+        ret, _out, _err = run_command ("vgcreate utilsTestVG %s --config \"devices {use_devicesfile = 0}\"" % self.loop_dev)
         self.assertEqual(ret, 0)
-        self.addCleanup(run_command, "vgremove -y utilsTestVG")
+        self.addCleanup(run_command, "vgremove -y utilsTestVG --config \"devices {use_devicesfile = 0}\"")
 
-        ret, _out, _err = run_command ("lvcreate -n utilsTestLV -L 12M utilsTestVG")
+        ret, _out, _err = run_command ("lvcreate -n utilsTestLV -L 12M utilsTestVG --config \"devices {use_devicesfile = 0}\"")
         self.assertEqual(ret, 0)
-        self.addCleanup(run_command, "lvremove -y utilsTestVG/utilsTestLV")
+        self.addCleanup(run_command, "lvremove -y utilsTestVG/utilsTestLV --config \"devices {use_devicesfile = 0}\"")
 
         symlinks = BlockDev.utils_get_device_symlinks("utilsTestVG/utilsTestLV")
         # there should be at least 4 symlinks for an LV
@@ -484,3 +500,25 @@ class UtilsLinuxKernelVersionTest(UtilsTestCase):
         self.assertEqual(ver.major, ver2.major)
         self.assertEqual(ver.minor, ver2.minor)
         self.assertEqual(ver.micro, ver2.micro)
+
+
+class UtilsKernelModuleTest(UtilsTestCase):
+    @tag_test(TestTags.NOSTORAGE, TestTags.CORE)
+    def test_have_kernel_module(self):
+        """ Test checking for kernel modules """
+
+        have = BlockDev.utils_have_kernel_module("definitely-not-existing-kernel-module")
+        self.assertFalse(have)
+
+        # loop should be everywhere, right?
+        have = BlockDev.utils_have_kernel_module("loop")
+        self.assertTrue(have)
+
+        # lets check some filesystems support and compare with 'modprobe' results
+        for fs in ("ext2", "ext3", "ext4", "xfs", "btrfs"):
+            have_fs = BlockDev.utils_have_kernel_module(fs)
+            ret, _out, _err = run_command("modprobe --dry-run %s" % fs)
+            if ret == 0:
+                self.assertTrue(have_fs)
+            else:
+                self.assertFalse(have_fs)
